@@ -1,7 +1,12 @@
+import re
 import requests
 from BeautifulSoup import BeautifulSoup as Soup
 from hippybot.hipchat import HipChatApi
 from hippybot.decorators import directcmd
+try:
+    import simplejson as json
+except ImportError:
+    import json
 
 UD_SEARCH_URI = "http://www.urbandictionary.com/iphone/search/define"
 
@@ -12,11 +17,12 @@ class Plugin(object):
 
     @directcmd
     def udefine(self, mess, args):
-        json = requests.get(UD_SEARCH_URI, params={'term': args})
+        term = args.strip()
+        req = requests.get(UD_SEARCH_URI, params={'term': term})
+        data = req.content
         results = []
-        if json:
-            json = json.replace(r'\r', '')
-            data = loads(json)
+        if data:
+            data = json.loads(data.replace(r'\r', ''))
             if data.get('result_type', '') != 'no_results' and \
                data.has_key('list') and len(data['list']) > 0:
                 for datum in data['list']:
@@ -31,5 +37,5 @@ class Plugin(object):
             reply = u"\n".join(results)
             return reply
         else:
-            return u'No matches found for "%s"' % (args,)
+            return u'No matches found for "%s"' % (term,)
 
